import { useMutation } from "@tanstack/react-query";
import { usersRoute } from ".";
import { queryClient } from "../../query-client";
import { QUERY_KEYS } from "../../query-keys";

export const useDeleteUser = () => {
    return useMutation({
        mutationFn: (id: string) => usersRoute.delete(`/users/${id}`),
        onSuccess: () => {
            queryClient.invalidateQueries({ queryKey: [QUERY_KEYS.USERS] });
        },
    });
};

export interface AdminUserData {
    name: string;
    cpf: string;
    email: string;
    phoneNumber: string;
    profile: string;
    password: string;
    confirmPassword: string;
    inviteId: string;
}

export interface LoginUserData {
    username: string;
    password: string;
}

export const useCreateUser = () => {
    return useMutation({
        mutationFn: (data: AdminUserData) => {
            const dto = { ...data };
            dto.cpf = data.cpf.replace(/\D/g, "");
            return usersRoute.post("/users/admin", dto);
        },
        onSuccess: () => {
            queryClient.invalidateQueries({ queryKey: [QUERY_KEYS.USERS] });
        },
    });
};
