import { useQuery } from "@tanstack/react-query";
import { usersRoute } from ".";
import { QUERY_KEYS } from "../../query-keys";

export interface UserData {
    id: string;
    phoneNumber: string;
    name: string;
    cpf: string;
    profile: string;
    email: string;
}

export interface UserGetAllResponse {
    content: UserData[];
    totalElements: number;
}

export const useGetAllUsers = (pageNumber: number, pageSize: number, search?: string) =>
    useQuery<UserGetAllResponse>({
        queryKey: [QUERY_KEYS.USERS, pageNumber, pageSize, search],
        queryFn: async () =>
            (
                await usersRoute.get(
                    `users?pageSize=${pageSize}&pageNumber=${pageNumber}&active=true${
                        search ? `&nameFilter=${search}` : ""
                    }`
                )
            ).data,
        enabled: pageNumber !== undefined && pageSize !== undefined,
    });

    export const useGetUserByID = (id: string) =>
    useQuery<UserData>({
        queryKey: [QUERY_KEYS.USERS , id],
        queryFn: async () =>
            (
                await usersRoute.get(
                    `/users/${id}`
                )
            ).data,
        enabled: id !== undefined && id !== null,
    });