import { Environment, UrlType } from "./enum";
import { createHttpClient } from "./http-client";

export function getEnvironmentRoute(type: UrlType): string {
    switch (import.meta.env.MODE) {
         case Environment.Local:
             return getLocalUrl(type);
        case Environment.Development:
        case Environment.Homologation:
        default:
            return getUrl(type);
    }
}

export const getBaseApi = (type: UrlType) => {
    const baseRoute = getEnvironmentRoute(type);
    return createHttpClient(baseRoute);
};

const getLocalUrl = (type: UrlType) => {
    const handledUrl = window.location.href.split("//")[1].split(":")[0];
    switch (type) {
        case UrlType.API:
            return "http://" + handledUrl + ":8081";
        case UrlType.AUTH:
            return "http://" + handledUrl + ":8080";
    }
};

const getUrl = (type: UrlType) => {
    switch (type) {
        case UrlType.API:
            return import.meta.env.VITE_API_URL;
        case UrlType.AUTH:
            return import.meta.env.VITE_AUTH_URL;
    }
};
