import { useQuery } from '@tanstack/react-query';
import { allCriminalProceduresRoute, criminalProceduresRoute } from '.';
import { QUERY_KEYS } from '../../query-keys';

export interface ProcedureData {
  reviewerId: any;
  active: any;
  victimId: any;
  description: string,
  id: string;
  procedureType: string;
  number: string;
  crime: {
    name: string;
  };
  city: { name: string };
  date: string;
}

export interface ProcedureGetAllResponse {
  content: ProcedureData[];
  totalElements: number;
}

export const useGetCriminalProcedures = (pageNumber: number, pageSize: number, search?: string) => {

    return useQuery<ProcedureGetAllResponse>({
      queryKey: [QUERY_KEYS.criminalProcedures, pageNumber, pageSize, search],
      queryFn: async () => (await allCriminalProceduresRoute.get(
        `criminal-procedures?size=${pageSize}&page=${pageNumber}&active=true${
          search ? `&numberFilter=${search}` : ""
      }`
    )).data,
      enabled: pageNumber !== undefined && pageSize !== undefined,
    });
  };
  
export const useGetCriminalProcedureByID = (processNumber: string) =>
  useQuery<ProcedureData>({
    queryKey: [QUERY_KEYS.criminalProcedures, processNumber],
    queryFn: async () => {
      return (await criminalProceduresRoute.get(`/${processNumber}`)).data
    },
    enabled: !!processNumber
  });
