import LogoutIcon from "@mui/icons-material/Logout";
import { Box, Container, Grid, List, ListItemButton, ListItemText } from "@mui/material";
import { Outlet, useLocation, useNavigate } from "react-router-dom";
import { CONVIDAR_USUARIO, PROCEDIMENTOS_CRIMINAIS, USUARIOS } from "../../app/Routes";
import { useAuth } from "../../hooks/useAuth";
import "./styles.css";

const Navigation = () => {
    const navigate = useNavigate();
    const location = useLocation();
    const { logout } = useAuth();

    const handleLogout = () => {
        sessionStorage.removeItem("API_TOKEN");
        logout();
        navigate("/login");
    };
    return (
        <Container disableGutters maxWidth={false} style={{overflow: 'hidden'}}>
            <Grid
                sx={{
                    display: "grid",
                    gridTemplateColumns: "1.5fr 6.5fr",
                    width: "100%",
                }}
            >
                <aside>
                    <Box
                        sx={{
                            backgroundColor: "#FB8500",
                            height: "100%",
                            display: "flex",
                            justifyContent: "center",
                            alignItems: "flex-start",
                            flexDirection: "column",
                            paddingLeft: 3,
                            paddingRight: 3,
                        }}
                    >
                        <List>
                            <ListItemButton
                                sx={{ display: "block" }}
                                disableRipple
                                selected={location.pathname === PROCEDIMENTOS_CRIMINAIS}
                                component="a"
                                onClick={() => navigate(PROCEDIMENTOS_CRIMINAIS)}
                            >
                                <ListItemText primary="Procedimentos Criminais" />
                            </ListItemButton>
                            <ListItemButton
                                sx={{ display: "block" }}
                                disableRipple
                                selected={location.pathname === CONVIDAR_USUARIO}
                                component="a"
                                onClick={() => navigate(CONVIDAR_USUARIO)}
                            >
                                <ListItemText primary="Convidar usuário" />
                            </ListItemButton>
                            <ListItemButton
                                sx={{ display: "block" }}
                                disableRipple
                                selected={location.pathname === USUARIOS}
                                component="a"
                                onClick={() => navigate(USUARIOS)}
                            >
                                <ListItemText primary="Usuários" />
                            </ListItemButton>
                        </List>
                    </Box>
                    <Box
                        sx={{
                            backgroundColor: "#FB8500",
                            height: "100%",
                            display: "flex",
                            justifyContent: "center",
                            alignItems: "flex-start",
                            flexDirection: "column",
                            paddingLeft: 3,
                            paddingRight: 3,
                        }}
                    >
                        <ListItemButton
                            disableRipple
                            sx={{
                                position: "absolute",
                                bottom: 10,
                                display: "flex",
                                flexDirection: "row",
                                alignContent: "center",
                            }}
                            onClick={() => handleLogout()}
                        >
                            <LogoutIcon sx={{ paddingRight: 2, color: "white", fontSize: 30 }} />
                            <ListItemText primary="Sair" />
                        </ListItemButton>
                    </Box>
                </aside>
                <Box sx={{ height: "100%", width: "100%" }}>
                    <Outlet />
                </Box>
            </Grid>
        </Container>
    );
};

export default Navigation;
