import { KeyboardArrowLeft, KeyboardArrowRight } from "@mui/icons-material";
import { Typography } from "@mui/material";

const stylesArrow = {
    colorDisable: {
        color: "#CCCCCC",
        margin: 0,
        padding: 0,
        cursor: "default",
    },
    colorEnable: { margin: 0, padding: 0, cursor: "pointer" },
};

const stylesArrowButton = { background: "transparent", border: "none" };

export interface Pagination {
    pageNumber: number;
    pageSize: number;
    totalElements: number;
    rowsLength: number;
}
interface Paginator {
    pagination: Pagination;
    onPageChange: (pagination: Pagination) => void;
}

export default function Paginator({ onPageChange, pagination }: Paginator) {
    const { pageNumber, pageSize, totalElements, rowsLength } = pagination;
    return (
        <div
            style={{
                display: "flex",
                flexDirection: "row",
                justifyContent: "flex-end",
                alignItems: "center",
                marginTop: 20,
            }}
        >
            <Typography variant="body1" style={{ marginRight: 5 }}>
                Mostrando:
            </Typography>
            <Typography variant="body1" style={{ margin: 0, padding: 0, marginRight: 10 }}>
                {rowsLength} de {totalElements} itens
            </Typography>
            <div style={{ margin: 0, padding: 0 }}>
                <button
                    style={stylesArrowButton}
                    onClick={() => onPageChange({ ...pagination, pageNumber: pageNumber - 1 })}
                    disabled={pageNumber + 1 <= 1}
                >
                    <KeyboardArrowLeft
                        style={Object.assign(
                            pageNumber + 1 <= 1 ? stylesArrow.colorDisable : stylesArrow.colorEnable
                        )}
                    />
                </button>
            </div>
            <div style={{ margin: 0, padding: 0 }}>
                <button
                    style={stylesArrowButton}
                    onClick={() => onPageChange({ ...pagination, pageNumber: pageNumber + 1 })}
                    disabled={pageNumber + 1 >= totalElements / pageSize}
                >
                    <KeyboardArrowRight
                        style={Object.assign(
                            pageNumber + 1 >= totalElements / pageSize
                                ? stylesArrow.colorDisable
                                : stylesArrow.colorEnable
                        )}
                    />
                </button>
            </div>
        </div>
    );
}
