import { createContext, ReactNode, useContext, useState } from 'react';
import authStorage  from '../api/authentication';
import { jwtDecode } from "jwt-decode";

type ProviderProps = { children: ReactNode };

interface JwtPayload {
  app_id: string;
}

const AuthContext = createContext<
  { authenticated: boolean; login: () => void; logout: () => void; id: string} | undefined
>(undefined);

const AuthProvider = ({ children }: ProviderProps) => {

  const login = () => {
    setAuthenticated(true);
  };

  const logout = () => {
    setAuthenticated(false);
  };

  const token = authStorage.getAuthenticationToken();
  const [authenticated, setAuthenticated] = useState(token != null);
  const [id] = useState( token != null ? jwtDecode<JwtPayload>(token)?.app_id : "");

  const value = {
    id,
    authenticated,
    login,
    logout,
  };

  return <AuthContext.Provider value={value}>{children}</AuthContext.Provider>;
};

const useAuth = () => {
  const context = useContext(AuthContext);
  if (context === undefined) {
    throw new Error('useAuth must be used within a AuthProvider');
  }
  return context;
};

// eslint-disable-next-line react-refresh/only-export-components
export { AuthProvider, useAuth };
