import Table from "../../components/Table";
import { ProcedureData, ProcedureGetAllResponse, useGetCriminalProcedures } from "../../api/public/criminal-procedures/queries";
import { useGetAllUsers } from "../../api/auth/users/queries";
import { useState, useEffect } from "react";
import { Pagination } from "../../components/Table/Paginator";
import throttle from "lodash.throttle";
import { Box } from "@mui/material";
import { useNavigate } from "react-router-dom";
import { PROCEDIMENTOS_CRIMINAIS } from "../../app/Routes";

export default function CriminalProcedures() {
    const cells = [
        {
            title: "Nome",
            jsonField: "name",
            width: "10%"
        },
        {
            title: "CPF",
            jsonField: "cpf",
            width: "10%"
        },
        {
            title: "Nº do procedimento criminal",
            jsonField: "number",
            width: "10%",
        },
        {
            title: "Data",
            jsonField: "date",
            width: "10%",
            type: 'date'
        },
        {
            title: "Cidade",
            jsonField: "cityName",
            width: "10%",
        },
        {
            title: "Status",
            jsonField: "active",
            width: "10%",
            mappedValue: (value: any) => {
                if (value) {
                    return "Ativo";
                }
                return "Inativo";
            }
        },
        {
            title: "Ações",
            jsonField: "number",
            type: "redirect",
            width: "5%",
        },
    ];

    const [pagination, setPagination] = useState<Pagination>({
        pageNumber: 0,
        pageSize: 10,
        totalElements: 0,
        rowsLength: 0,
    });

    const [search, setSearch] = useState("");

    const {
        data: users,
        error: usersError,
        isFetching: isUsersFetching,
    } = useGetAllUsers(0, 300);

    const {
        data: criminalProcedures,
        error: criminalProceduresErrors,
        isFetching: isCriminalProceduresFetching,
    } = useGetCriminalProcedures(pagination.pageNumber, pagination.pageSize, search);

    const [combinedData, setCombinedData] = useState<ProcedureGetAllResponse>({ content: [], totalElements: 0 });

    const navigate = useNavigate();

    useEffect(() => {
        if (criminalProcedures && users) {
            const usersData = users.content;

            const usersMap = new Map(usersData.map((user: { id: string, cpf: string, name: string }) => [user.id, user]));

            const mergedContent = criminalProcedures.content.map((procedure: { victimId: string; city: { name: string; }; active: boolean; }) => {
                const user = usersMap.get(procedure.victimId);
                return {
                    ...procedure,
                    name: user ? user.name : 'Não encontrado',
                    cpf: user ? user.cpf : 'Não encontrado',
                    cityName: procedure.city.name,
                    active: procedure.active ? 'Ativo' : 'Inativo',
                };
            })
            setCombinedData({
                ...criminalProcedures,
                totalElements: mergedContent.length,
                content: mergedContent as unknown as ProcedureData[]
            });
            pagination.totalElements = criminalProcedures.totalElements;
        }
    }, [criminalProcedures, users]);

    return (
        <Box sx={{ margin: "1rem" }}>
            <Table
                error={!!criminalProceduresErrors || !!usersError}
                loading={isUsersFetching || isCriminalProceduresFetching}
                rows={combinedData?.content || []}
                pagination={{ ...pagination, totalElements: criminalProcedures?.totalElements || 0 }}
                cells={cells}
                tableName={"Procedimentos Criminais"}
                onSearch={(search) => throttle(() => setSearch(search), 1000)()}
                onPageChange={(pagination) => setPagination(pagination)}
                onRedirect={(id) => navigate(PROCEDIMENTOS_CRIMINAIS+`/${id}`)}
            />
        </Box>
    );

}
