import LoadingButton from "@mui/lab/LoadingButton";
import { Box, CircularProgress, TextField, colors } from "@mui/material";
import { useState } from "react";
import { Credentials, useLogin } from "../../api/auth/login/mutations";
import { PROCEDIMENTOS_CRIMINAIS } from "../../app/Routes";
import FormContainer from "../../components/FormContainer";
import { isCPFValid } from "../../validators/CPFValidator";

function Login() {

    const login = useLogin();
    const [loading, setLoading] = useState(false);

    const [form, setForm] = useState({
        cpf: "",
        password: "",
    } as Credentials);

    const [formErrors, setFormErrors] = useState({
        cpf: "",
        password: "",
    });
    const [errorMessage, setErrorMessage] = useState("");

    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    function handleSubmit(event: any) {
        event.preventDefault();
        setLoading(true);
        const isValid = validateForm();

        if (isValid) {
            login.mutate(
                { cpf: form.cpf.replace(/\D/g, ""), password: form.password },
                {
                    onSuccess: () => {
                        setLoading(false);
                        window.location.replace(location.protocol + '//' + location.host + PROCEDIMENTOS_CRIMINAIS)
                    },
                    // eslint-disable-next-line @typescript-eslint/no-explicit-any
                    onError: (e: any) => {
                        setErrorMessage(e.response.data.message ?? e.message);
                        setLoading(false);
                    },
                }
            );
        } else {
            setLoading(false);
        }
    }

    const handleCpfChange = (event: { target: { value: string } }) => {
        setFormErrors({ ...formErrors, cpf: "" });
        const numericValue = event.target.value.replace(/\D/g, "");
        setForm({ ...form, cpf: numericValue });

        if (numericValue.length === 11) {
            const formattedNumber = `${numericValue.slice(0, 3)}.${numericValue.slice(
                3,
                6
            )}.${numericValue.slice(6, 9)}-${numericValue.slice(9, 11)}`;
            setForm({ ...form, cpf: formattedNumber });
        }
    };

    const handlePasswordChange = (event: { target: { value: string } }) => {
        setFormErrors({ ...formErrors, password: "" });
        setForm({ ...form, password: event.target.value });
    };

    const validateForm = () => {
        const errors = { ...formErrors };

        errors.cpf = validateCPF(form.cpf);
        errors.password = validatePassword(form.password);

        setFormErrors(errors);

        if (errors.cpf === "" && errors.password === "") {
            return true;
        } else {
            return false;
        }
    };

    const validateCPF = (cpf: string) => {
        if (!isCPFValid(cpf.replace(/\D/g, ""))) {
            return "Por favor, informe um CPF válido";
        }
        return "";
    };

    const validatePassword = (password: string) => {
        if (password.length === 0) {
            return "Por favor, informe uma senha válida";
        }
        return "";
    };

    return (
        <FormContainer>
            <div
                style={{
                    display: "flex",
                    flexDirection: "column",
                    justifyContent: "center",
                    alignItems: "center",
                    height: "100%",
                    marginRight: 40,
                }}
            >
                <div
                    style={{
                        alignItems: "center",
                        display: "flex",
                        flexDirection: "column",
                    }}
                >
                    <h1 style={{ color: "#FB8500" }}>Bem-vindo à plataforma Vítimas de Crime</h1>
                    <p style={{ color: colors.grey[600] }}>Faça login para acessar a plataforma </p>
                </div>
                <form
                    style={{
                        display: "flex",
                        flexDirection: "column",
                        alignItems: "center",
                        justifyContent: "center",
                        width: "100%",
                        paddingTop: 50,
                    }}
                    onSubmit={handleSubmit}
                >
                    <TextField
                        type="text"
                        color="warning"
                        label="CPF"
                        error={formErrors.cpf !== "" || !!errorMessage}
                        onChange={(e) => handleCpfChange(e)}
                        value={form.cpf}
                        fullWidth
                        sx={{ mb: 4 }}
                    />

                    <TextField
                        type="password"
                        color="warning"
                        label="Senha"
                        onChange={(e) => handlePasswordChange(e)}
                        error={formErrors.password !== "" || !!errorMessage}
                        helperText={formErrors.password}
                        value={form.password}
                        fullWidth
                        sx={{ mb: 4 }}
                    />

                    {errorMessage && <Box sx={{ color: colors.red[500] }}>{errorMessage}</Box>}

                    <LoadingButton
                        style={{
                            margin: "10px",
                            padding: "15px",
                            borderRadius: "30px",
                            background: "linear-gradient(to right, #FFB703, #FB8500)",
                            boxShadow: "0px 2px 4px rgba(0, 0, 0.4, 0.3)",
                            color: "white",
                            width: "50%",
                            height: "3rem",
                            alignSelf: "center",
                            borderColor: "#FFB703",
                        }}
                        loadingIndicator={<CircularProgress style={{ color: "white" }} size={26} />}
                        type="submit"
                        loading={loading}
                    >
                        {!loading ? "CONTINUAR" : " "}
                    </LoadingButton>
                </form>
            </div>
        </FormContainer>
    );
}

export default Login;
