import { Alert, CircularProgress, Snackbar } from "@mui/material";
import "./userInvite.css";
import Box from "@mui/material/Box";
import TextField from "@mui/material/TextField";
import { useState } from "react";
import { usePostInvite } from "../../api/public/invite/mutations";
import { LoadingButton } from "@mui/lab";

function SendInvite() {
    const postInvite = usePostInvite();

    const [successSnackbar, setSuccessSnackbar] = useState(false);
    const [loading, setLoading] = useState(false);

    const [errorSnackbar, setErrorSnackbar] = useState(false);
    const [errorMessage, setErrorMessage] = useState("");

    const handleInviteButton = () => {
        if (isFormValid()) {
            setLoading(true);
            postInvite.mutate(form, {
                onSuccess: () => {
                    setSuccessSnackbar(true);
                    setLoading(false);
                },
                onError: (e: any) => {
                    setErrorMessage(e.response.data.message ?? e.message);
                    setErrorSnackbar(true);
                    setLoading(false);
                }
            });
        }
    };

    const [form, setForm] = useState({
        email: "",
    });

    const [formErrors, setFormErrors] = useState({
        email: "",
        hasError: false,
    });

    const handleEmailValidation = (email: string | any) => {
        const regex = /\S+@\S+\.\S+/;
        if (email.length !== 0 && !regex.test(email)) {
            setFormErrors({ email: "Formato de e-mail inválido.", hasError: true });
        } else {
            setFormErrors({ email: "", hasError: false });
        }
    };

    const handleTextFieldChange = (event: { target: { value: any } }) => {
        const email = event.target.value;
        setForm({ ...form, email: email });
        handleEmailValidation(email);
    };

    const isFormValid = () => {
        return form.email !== "" && !formErrors.hasError;
    };

    return (
        <>
            <div style={{ paddingLeft: "38px", paddingTop: "25px" }}>
                <h1 className="title" style={{ marginBottom: "15px" }}>
                    Convidar usuário
                </h1>
                <Box
                    sx={{
                        width: 500,
                        maxWidth: "100%",
                        textAlign: "left",
                    }}
                >
                    <TextField
                        sx={{
                            borderRadius: "5px",
                            marginBottom: "30px",
                            boxShadow: formErrors.hasError
                                ? "none"
                                : "0px 2px 4px rgba(0, 0, 0.4, 0.3)",
                        }}
                        onChange={handleTextFieldChange}
                        fullWidth
                        label="Insira o E-mail do usuário que será convidado"
                        variant="outlined"
                        color="warning"
                        error={formErrors.hasError}
                        helperText={formErrors.email}
                        InputLabelProps={{
                            style: {
                                fontFamily: "sans-serif",
                                color: "black",
                                fontSize: 13,
                                textAlign: "left",
                                opacity: 0.3,
                            },
                        }}
                    />

                    <LoadingButton
                        onClick={handleInviteButton}
                        disabled={!isFormValid()}
                        style={{
                            margin: "10px",
                            padding: "15px",
                            borderRadius: "30px",
                            background: "linear-gradient(to right, #FFB703, #FB8500)",
                            boxShadow: "0px 2px 4px rgba(0, 0, 0.4, 0.3)",
                            color: "white",
                            width: "50%",
                            height: "3rem",
                            alignSelf: "center",
                            borderColor: "#FFB703",
                        }}
                        loadingIndicator={<CircularProgress style={{ color: "white" }} size={26} />}
                        type="submit"
                        loading={loading}
                    >
                        {!loading ? "CONTINUAR" : " "}
                    </LoadingButton>
                </Box>
            </div>
            <Snackbar
                open={successSnackbar}
                autoHideDuration={6000}
                onClose={() => setSuccessSnackbar(false)}
            >
                <Alert
                    onClose={() => setSuccessSnackbar(false)}
                    severity="success"
                    sx={{ width: "100%" }}
                >
                    Convite enviado com sucesso!
                </Alert>
            </Snackbar>
            <Snackbar
                open={errorSnackbar}
                autoHideDuration={6000}
                onClose={() => setErrorSnackbar(false)}
            >
                <Alert
                    onClose={() => setErrorSnackbar(false)}
                    severity="error"
                    sx={{ width: "100%" }}
                >
                    {errorMessage}
                </Alert>
            </Snackbar>
        </>
    );
}

export default SendInvite;
