import { Box } from "@mui/material";
import throttle from "lodash.throttle";
import { useState } from "react";
import { useDeleteUser } from "../../api/auth/users/mutations";
import { useGetAllUsers } from "../../api/auth/users/queries";
import Table from "../../components/Table";
import { Pagination } from "../../components/Table/Paginator";

export default function Users() {
    const cells = [
        {
            title: "Nome",
            jsonField: "name",
            width: "24%",
        },
        {
            title: "Email",
            jsonField: "email",
            width: "24%",
        },
        {
            title: "Telefone",
            jsonField: "phoneNumber",
            width: "24%",
        },
        {
            title: "CPF",
            jsonField: "cpf",
            width: "24%",
        },
        {
            title: "Ações",
            jsonField: "id",
            type: "delete",
            width: "5%",
        },
    ];

    const [pagination, setPagination] = useState<Pagination>({
        pageNumber: 0,
        pageSize: 10,
        totalElements: 0,
        rowsLength: 0,
    });

    const [search, setSearch] = useState("");

    const { mutate: deleteUser, error: deleteError, isPending } = useDeleteUser();
    const {
        data: users,
        error: usersError,
        isFetching,
    } = useGetAllUsers(pagination.pageNumber, pagination.pageSize, search);

    return (
        <Box sx={{ margin: "1rem" }}>
            <Table
                error={!!deleteError || !!usersError}
                loading={isPending || isFetching}
                rows={users?.content || []}
                pagination={{ ...pagination, totalElements: users?.totalElements || 0 }}
                cells={cells}
                tableName={"Usuários"}
                onSearch={(search) => throttle(() => setSearch(search), 1000)()}
                onPageChange={(pagination) => setPagination(pagination)}
                onDelete={(id) => deleteUser(id)}
            />
        </Box>
    );
}
